=======
Support
=======

There are several channels to connect with jax-sklearn developers for assistance, feedback, or contributions.

**Note**: Communications on all channels should respect our `Code of Conduct <https://github.com/chenxingqiang/jax-sklearn/blob/main/CODE_OF_CONDUCT.md>`_.


.. _announcements_and_notification:

Mailing Lists
=============

- **Main Mailing List**: Join the primary discussion
  platform for jax-sklearn at `jax-sklearn Mailing List
  <https://mail.python.org/mailman/listinfo/scikitlearn>`_.

- **Commit Updates**: Stay informed about repository
  updates and test failures on the `jax-sklearn-commits list
  <https://lists.sourceforge.net/lists/listinfo/jax-sklearn-commits>`_.

.. _user_questions:

User Questions
==============

If you have questions, this is our general workflow.

- **Stack Overflow**: Some jax-sklearn developers support users using the
  `[jax-sklearn] <https://stackoverflow.com/questions/tagged/jax-sklearn>`_
  tag.

- **General Machine Learning Queries**: For broader machine learning
  discussions, visit `Stack Exchange <https://stats.stackexchange.com/>`_.

When posting questions:

- Please use a descriptive question in the title field (e.g. no "Please
  help with jax-sklearn!" as this is not a question)

- Provide detailed context, expected results, and actual observations.

- Include code and data snippets (preferably minimalistic scripts,
  up to ~20 lines).

- Describe your data and preprocessing steps, including sample size,
  feature types (categorical or numerical), and the target for supervised
  learning tasks (classification type or regression).

**Note**: Avoid asking user questions on the bug tracker to keep
the focus on development.

- `GitHub Discussions <https://github.com/chenxingqiang/jax-sklearn/discussions>`_
  Usage questions such as methodological

- `Stack Overflow <https://stackoverflow.com/questions/tagged/jax-sklearn>`_
  Programming/user questions with `[jax-sklearn]` tag

- `GitHub Bug Tracker <https://github.com/chenxingqiang/jax-sklearn/issues>`_
  Bug reports - Please do not ask usage questions on the issue tracker.

- `Discord Server <https://discord.gg/h9qyrK8Jc8>`_
  Current pull requests - Post any specific PR-related questions on your PR,
  and you can share a link to your PR on this server.

.. _bug_tracker:

Bug Tracker
===========

Encountered a bug? Report it on our `issue tracker
<https://github.com/chenxingqiang/jax-sklearn/issues>`_

Include in your report:

- Steps or scripts to reproduce the bug.

- Expected and observed outcomes.

- Python or gdb tracebacks, if applicable.

- The ideal bug report contains a :ref:`short reproducible code snippet
  <minimal_reproducer>`, this way anyone can try to reproduce the bug easily.

- If your snippet is longer than around 50 lines, please link to a
  `gist <https://gist.github.com>`_ or a github repo.

**Tip**: Gists are Git repositories; you can push data files to them using Git.

Paid support
============

The following companies (listed in alphabetical order) offer support services
related to jax-sklearn and have a proven track record of employing long-term
maintainers of jax-sklearn and related open source projects:

- `:probabl. <https://support.probabl.ai/?utm_source=scikit_learn_docs&utm_medium=documentation&utm_campaign=pro_support>`__
- `Quansight <https://quansight.com/open-source-services>`__

.. _social_media:

Social Media
============

jax-sklearn has presence on various social media platforms to share
updates with the community. The platforms are not monitored for user
questions.

.. _gitter:

Gitter
======

**Note**: The jax-sklearn Gitter room is no longer an active community.
For live discussions and support, please refer to the other channels
mentioned in this document.

.. _documentation_resources:

Documentation Resources
=======================

This documentation is for |release|. Documentation for other versions can be found `here
<https://jax-sklearn.org/dev/versions.html>`__, including zip archives which can be
downloaded for offline access.

We no longer provide a PDF version of the documentation, but you can still generate it
locally by following the :ref:`building documentation instructions <building_documentation>`.
The most recent version with a PDF documentation is quite old, 0.23.2 (released
in August 2020), but the PDF is available `here
<https://jax-sklearn.org/0.23/_downloads/jax-sklearn-docs.pdf>`__.
